# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`luet`](#luet): Manages the luet package manager
* [`luet::migrate::entropy`](#luetmigrateentropy): Migrates an entropy system to luet
* [`luet::ready`](#luetready): Anchor class used for delaying resources until luet is ready for use

#### Private Classes

* `luet::install`: Handles the installation of luet itself

### Data types

* [`Luet::InstallMethod`](#luetinstallmethod): Defines the available installation methods for luet
* [`Luet::MigrateBackend`](#luetmigratebackend): Defines the types of package manager luet supports migrations from

### Tasks

* [`cleanup`](#cleanup): Run `luet cleanup` on target nodes to free up disk space used by downloaded packages
* [`update`](#update): Run `luet repo update` on target nodes to refresh repository definitions

## Classes

### `luet`

Manages the luet package manager

#### Examples

##### Install from existing systems package manager

```puppet
class { 'luet':
  manage_install => true,
  install_method => 'repo',
}
```

##### Install from MocaccinoOS website

```puppet
class { 'luet':
  manage_install => true,
  install_method => 'source',
}
```

##### Use with pre-installed luet

```puppet
include luet
```

##### Migrate system from Entropy to Luet

```puppet
# Via luet class
class { 'luet':
  migrate_from => ['entropy']
}

# Or by explicitly including the entropy migration class
include luet::migrate::entropy
```

#### Parameters

The following parameters are available in the `luet` class.

##### `manage_install`

Data type: `Boolean`

Defines whether this module should attempt to install the luet package manager

Default value: ``false``

##### `install_method`

Data type: `Luet::InstallMethod`

Defines how luet should be installed

Default value: `'repo'`

##### `package_name`

Data type: `String`

Name of the luet package when installed using `repo` method

Default value: `'luet'`

##### `package_ensure`

Data type: `String`

Ensure for the luet package when installed using the `repo` method

Default value: `'installed'`

##### `migrate_from`

Data type: `Array[Luet::MigrateBackend]`

A lit of package managers which luet should migrate from

Default value: `[]`

### `luet::migrate::entropy`

This class runs the `luet migrate-entropy` command once to reflect
that the contents of the entropy package database are installed
within the luet package database.

This class should be included in the catalog for systems you
want to be migrated to luet.

### `luet::ready`

This class can be used as a dependency on other resources in the catalog
which should be delayed until after luet is ready for use.

This class is not complete until luet has been installed (if installation is
being managed by this class), and all enabled migrations have been completed.

This will prevent, for example, luet packages being installed and
overwriting the content of packages already installed via the previous
package manager, before the migration into the luet database has been done.

* **Note** Any package resource which specifies the `luet` provider will automatically
depend on the `luet::ready` class. This construct is only needed where a provider
is not explicitly set. When the provider is not set, the default provider is
resolved by the agent at catalog application time, so it's not possible to know
at compilation time which provider is going to be used.

#### Examples

##### Delay installation of a specific package until Luet is ready

```puppet
package { 'htop':
  ensure   => present,
  category => 'sys-process',
  require  => Class['luet::ready']
}
```

##### Configure all packages on a system to use luet when ready

```puppet
# in manifests/site.pp
if $operatingsystem == 'MocaccinoOS' {
  Package {
    provider => 'luet',
    require  => Class['luet::ready'],
  }
}
```

## Data types

### `Luet::InstallMethod`

Defines the available installation methods for luet

Alias of `Enum['repo', 'source']`

### `Luet::MigrateBackend`

Defines the types of package manager luet supports migrations from

Alias of `Enum['entropy']`

## Tasks

### `cleanup`

Run `luet cleanup` on target nodes to free up disk space used by downloaded packages

**Supports noop?** false

### `update`

Run `luet repo update` on target nodes to refresh repository definitions

**Supports noop?** false

#### Parameters

##### `repo`

Data type: `Optional[Pattern[/^[a-zA-Z0-9._-]+$/]]`

Restrict update to only this named repository

